@@ -9,26 +9,40 @@
 
 #include <QAbstractListModel>
 #include <QObject>
+#include <QQmlEngine>
 #include <QTimer>
 
 #include <array>
 #include <tuple>
 
+#include <qqmlintegration.h>
+
+class QJSEngine;
+
 class WeekModel;
 class KclockFormat : public QObject
 {
     Q_OBJECT
+    QML_NAMED_ELEMENT(KClockFormat)
+    QML_SINGLETON
     Q_PROPERTY(QString currentTime READ currentTime NOTIFY timeChanged)
 
 public:
-    explicit KclockFormat(QObject *parent = nullptr);
-
     static KclockFormat *instance()
     {
         static KclockFormat *singleton = new KclockFormat();
         return singleton;
     };
 
+    static KclockFormat *create(QQmlEngine *qmlEngine, QJSEngine *jsEngine)
+    {
+        Q_UNUSED(qmlEngine);
+        Q_UNUSED(jsEngine);
+        auto *format = instance();
+        QQmlEngine::setObjectOwnership(format, QQmlEngine::CppOwnership);
+        return format;
+    }
+
     QString currentTime() const;
     QString formatTimeString(int hours, int minutes);
     Q_INVOKABLE bool isChecked(int dayIndex, int daysOfWeek);
@@ -40,10 +54,11 @@ Q_SIGNALS:
     void timeChanged();
 
 private:
+    explicit KclockFormat(QObject *parent = nullptr);
+
     void startTimer(); // basic settings for updating time display
 
     QTimer *m_timer;
-    WeekModel *m_weekModel;
     QString m_currentTime;
 };
 
@@ -52,6 +67,8 @@ using weekListItem = std::array<std::tuple<QString, int>, 7>;
 class WeekModel : public QAbstractListModel
 {
     Q_OBJECT
+    QML_ELEMENT
+    QML_SINGLETON
 
 public:
     enum {
