@@ -69,12 +69,11 @@ Alarm::~Alarm()
 void Alarm::init(AlarmModel *parent)
 {
     // setup notification
-    m_notification->setIconName(QStringLiteral("kclock"));
     m_notification->setTitle(name() == QString() ? i18n("Alarm") : name());
     m_notification->setText(QLocale::system().toString(QTime::currentTime(), QLocale::ShortFormat));
     m_notification->setAutoDelete(false); // don't auto-delete when closing
 
-    auto defaultAction = m_notification->addDefaultAction(i18n("View"));
+    auto defaultAction = m_notification->addDefaultAction(i18nc("@action:button", "Dismiss"));
     connect(defaultAction, &KNotificationAction::activated, this, &Alarm::dismiss);
 
     auto dismissAction = m_notification->addAction(i18n("Dismiss"));
@@ -98,9 +97,6 @@ void Alarm::init(AlarmModel *parent)
     // setup dbus
     new AlarmAdaptor(this);
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/Alarms/") + m_uuid.toString(QUuid::Id128), this);
-    connect(this, &QObject::destroyed, [this] {
-        QDBusConnection::sessionBus().unregisterObject(QStringLiteral("/Alarms/") + m_uuid.toString(QUuid::Id128), QDBusConnection::UnregisterNode);
-    });
 
     // setup ringing length timer
     connect(m_ringTimer, &QTimer::timeout, this, []() {
@@ -305,7 +301,8 @@ void Alarm::ring()
 
     // play sound (it will loop)
     qDebug() << "Alarm sound: " << m_audioPath;
-    AlarmPlayer::instance().setSource(m_audioPath);
+    // TODO clean up usage of audio path as URL.
+    AlarmPlayer::instance().setSource(m_audioPath.toLocalFile());
     AlarmPlayer::instance().play();
     setRinging(true);
 
