@@ -18,6 +18,8 @@
 #include <QDBusReply>
 #include <QDebug>
 #include <QLocale>
+#include <QProcess>
+#include <QStandardPaths>
 
 AlarmModel *AlarmModel::instance()
 {
@@ -71,6 +73,21 @@ void AlarmModel::configureWakeups()
     scheduleAlarm();
 }
 
+QList<Alarm *> AlarmModel::alarmsList() const
+{
+    return m_alarmsList;
+}
+
+Alarm *AlarmModel::alarm(const QString &uuid) const
+{
+    for (Alarm *alarm : m_alarmsList) {
+        if (alarm->uuid() == uuid) {
+            return alarm;
+        }
+    }
+    return nullptr;
+}
+
 quint64 AlarmModel::getNextAlarm()
 {
     return m_nextAlarmTime;
@@ -201,9 +218,25 @@ void AlarmModel::initNotifierItem()
         m_item->setStandardActionsEnabled(false);
         m_item->setCategory(KStatusNotifierItem::SystemServices);
         m_item->setStatus(KStatusNotifierItem::Passive);
+        connect(m_item, &KStatusNotifierItem::activateRequested, this, &AlarmModel::notifierItemActivated);
     }
 }
 
+void AlarmModel::notifierItemActivated()
+{
+    // Don't want to pull in KIO just for CommandLauncherJob...
+    QProcess process;
+    process.setProgram(QStandardPaths::findExecutable(QStringLiteral("kclock")));
+    process.setArguments({QStringLiteral("--page"), QStringLiteral("Alarms")});
+    process.setProcessChannelMode(QProcess::ForwardedChannels);
+
+    QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
+    env.insert(QStringLiteral("XDG_ACTIVATION_TOKEN"), m_item->providedToken());
+    process.setProcessEnvironment(env);
+
+    process.startDetached();
+}
+
 void AlarmModel::updateNotifierItem(quint64 time)
 {
     if (time == 0) {
